module.exports = defineTest({
	description: 'correctly handles combined namespace reexports',
	options: {
		input: ['main1', 'main2']
	}
});
